# GitFix

Terminal application to help recover from a broken git state.

## Screenshots

![GitFix Screenshots](https://raw.githubusercontent.com/lucasmelin/gitfix/main/docs/assets/uncommitted.png?token=AABSHC7LZSRH6YORY6XWSB3BAXHY2)

## Installation

With `pip`:
```
pip install gitfix
```

With `pipx`:
```
pipx install gitfix
```

Optionally, see the releases page to download a binary for Windows. Rename the executable to `gitfix.exe` and add it to a directory in your `PATH`.

## Acknowledgements

- GitFixUm steps from https://sethrobertson.github.io/GitFixUm/, copyright © 2012 Seth Robertson, used under CC-BY-SA-3.0 with modifications.
- Rich markdown table formatting from @aurium in https://github.com/googlefonts/fontbakery/pull/3227

## Similar content
- https://dangitgit.com/en
- http://justinhileman.info/article/git-pretty/